/****************************************************************************
 *
 * Copyright (c) 2010-2012, EBM WebSourcing
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA 
 *
 *****************************************************************************/
package org.ow2.petals.cli.api.command;

import static org.junit.Assert.assertEquals;

import java.io.PrintStream;
import java.util.HashMap;
import java.util.Map;

import org.junit.Test;
import org.ow2.petals.cli.api.exception.DuplicatedCommandException;
import org.ow2.petals.cli.api.exception.ShellException;
import org.ow2.petals.cli.api.shell.Shell;

public class CommandRegistrationTestCase {

    private class CommandRegistratorShell implements Shell {

        private final Map<String, Command> commands = new HashMap<String, Command>();

        @Override
        public void registersCommand(final Command command) throws DuplicatedCommandException,
                IllegalArgumentException {
            this.commands.put(command.getName(), command);
        }

        @Override
        public Map<String, Command> getCommands() {
            return this.commands;
        }

        @Override
        public void exit(int status) {

        }

        @Override
        public void setExitStatus(int exitStatus) {

        }

        @Override
        public PrintStream getPrintStream() {
            return null;
        }

        @Override
        public String interpolate(String str) {
            return null;
        }

        @Override
        public PrintStream getErrorStream() {
            return null;
        }

        @Override
        public String askQuestion(final String question, final boolean isReplyPassword)
                throws ShellException {
            return null;
        }

        @Override
        public boolean confirms(final String message) throws ShellException {
            return false;
        }

        @Override
        public boolean isInteractive() {
            return false;
        }

        @Override
        public void setPrompt(final String prompt) {
        }

        @Override
        public boolean isDebugModeEnable() {
            return false;
        }
    }

    @Test
    public void testRegisterCommands_00() {

        final CommandRegistratorShell crs = new CommandRegistratorShell();
        CommandRegistration.registers(crs);
        final Command nullCommand = new NullCommand();

        final Map<String, Command> commands = crs.getCommands();
        assertEquals("Too much commands registered", 1, commands.size());
        assertEquals("Unexpected registered command", nullCommand.getName(),
                commands.get(nullCommand.getName()).getName());
    }

}
